
HWE.exact <- function(object, marker, founderOnly=TRUE)
{
  ##  if(!is.genotype(x))
  ##    stop("x must be of class 'genotype' or 'haplotype'")

  METHOD <- "Exact Test for Hardy-Weinberg Equilibrium"
  DNAME <- deparse(substitute(object))

  if(founderOnly==TRUE)
  { object<-founderGeneSet(object) }

  
  if(nallele(object,marker) != 2)
    {
      warning("Exact HWE test can only be computed for 2 markers with 2 alleles")
      retval <- list(statistic = NA,
                     parameter = NA,
                     p.value = NA,
                     method = METHOD,
                     data.name = DNAME,
                     observed = NULL)
      class(retval) = "htest"
      return(retval)
    }


  ## allele.tab <- table( factor(allele(x,1), levels=allele.names(x)),
  ##                      factor(allele(x,2), levels=allele.names(x)) )
  levs <- unlist(alleleLevels(object,marker))
  flag <- levs %in% missingCodes(object, marker, drop=FALSE)
  levs <- levs[!flag]
  
  allele.tab <-
    table(
          factor(
                 alleles(object, which=1, marker=marker),
                 levels = levs
                 )
          , 
          factor(
                 alleles(object, which=2, marker=marker),
                 levels = levs
                 )
          )

  
  n11 <- allele.tab[1,1]
  n12 <- allele.tab[1,2] + allele.tab[2,1]
  n22 <- allele.tab[2,2]
  
  n1 <- 2*n11+n12
  n2 <- 2*n22+n12

  
  dhwe2 <- function(n11, n12, n22) {
    f <- function(x) lgamma(x+1)
    n <- n11+n12+n22
    n1 <- 2*n11+n12
    n2 <- 2*n22+n12
    exp(log(2)*(n12) + f(n) - f(n11) - f(n12) - f(n22) - f(2*n) +
        f(n1) + f(n2))
  }


  x12 <- seq(n1 %% 2,min(n1,n2),2)
  x11 <- (n1-x12)/2
  x22 <- (n2-x12)/2
  mydist <- data.frame(n11=x11,n12=x12,n22=x22,density=dhwe2(x11,x12,x22))
  mydist <- mydist[order(mydist$density),]

  STATISTIC <- c("N11"=n11,"N12"=n12,"N22"=n22)
  PARAMETER <- c("N1"=n1,"N2"=n2)
  PVAL <- cumsum(mydist$density)[mydist$n11==n11 &
                               mydist$n12==n12 &
                               mydist$n22==n22] 
  
  retval <- list(statistic = STATISTIC,
                 parameter = PARAMETER,
                 p.value = PVAL,
                 method = METHOD,
                 data.name = DNAME,
                 observed = allele.tab)
  class(retval) = "htest"
  return(retval)

}

