## # compute allele frequencies
## 
## # two implementations, used the faster one!
## 
## alleleFreq1.geneSet <- function(object, marker=markerNames(object), allele=alleleLevels(object))
##   {
##     if(!is.list(allele))
##       {
##         allele <- rep(list(allele), length=length(marker))
##         names(allele) <- marker
##       }
## 
## 
##     aFreq <- function(m, object, allele)
##       {
##         retval <- rep(NA, length=length(allele[[m]]))
##         names(retval) <- allele[[m]]
## 
##         tmp <- sapply(allele[[m]],
##                       function(A)
## 
##                       {
##                         mean(allele.count(object=object,
##                                           marker=m, value=A)/2,
##                              na.rm=T)
##                       }
##                       )
##         tmp
##       }
## 
##     lapply(marker, aFreq, object=object, allele=allele)
## 
##   }
## 
## 
## alleleFreq2.geneSet <- function(object, marker=markerNames(object), allele=alleleLevels(object))
##   {
##     if(!is.list(allele))
##       {
##         allele <- rep(list(allele), length=length(marker))
##         names(allele) <- marker
##       }
##     retval <- rep( list(), length=length(marker) )
##     names(retval) <- marker
## 
##     for(m in marker)
##       {
##         retval[[m]] <- rep(NA, length(allele[[m]]))
##         names(retval[[m]]) <- allele[[m]]
##         alleleTab <- unlist(alleles(object, 1:2))
##         for(a in allele[[m]])
##           retval[[m]][a] <- mean(alleleTab==a, na.rm=T)/2
##       }
## 
##     retval
##   }
## 
## 
## 
## alleleFreq3.geneSet <- function(object, marker=markerNames(object), allele=alleleLevels(object))
##   {
##     if(!is.list(allele))
##       {
##         allele <- rep(list(allele), length=length(marker))
##         names(allele) <- marker
##       }
##     retval <- rep( list(), length=length(marker) )
##     names(retval) <- marker
## 
##     for(m in marker)
##       {
##         cc <- callCodes(object,m)
##         tt <- transTables(object,m)[,2:3]
##         for(a in allele[[m]])
##           {
##             ct <- apply(tt, 1, function(x) sum(x==a,na.rm=T))
##             ac <- ct[cc]
##             fq <- mean(ac,na.rm=TRUE)/2
##             retval[[m]][a] <- fq
##           }
##       }
## 
##     retval
##   }
##

alleleFreq.geneSet <- function(
                               object,
                               allele=alleleLevels(object, marker),
                               marker=markerNames(object),
                               as.list=TRUE,  # return as a list instead of a
                                               # matrix
                               ...
                               )
  {
    if(!is.character(marker))
       marker <- markerNames(object)[marker]
    
    if(!is.list(allele))
      {
        allele <- rep(list(allele), length=length(marker))
        names(allele) <- marker
      }

    count <- alleleCount(object=object, value=allele, marker=marker)
    tmp <- apply(count, 2, mean, na.rm=TRUE)/2
    if(as.list)
      {
        markerNames <- gsub("\\..*$","",names(tmp))
        tmp <- split(tmp, markerNames)
        tmp <- lapply(tmp,
                      function(x)
                      {
                        names(x) <- gsub("^.*\\.","",names(x))
                        x
                      }
                      )
      }

    return(tmp)
  }

setGeneric("alleleFreq", function(object, allele, marker, ...)
           standardGeneric("alleleFreq"))

setMethod("alleleFreq", "geneSet", alleleFreq.geneSet)

