as.geneSet <- function(x, ... )
  UseMethod("as.geneSet")

as.geneSet.matrix <- function(x, ...)
  as.geneSet(as.data.frame(x), ...)

as.geneSet.data.frame <- function(x, gene.columns,
                                  format=c("single","adjacent"),
                                  ploidy=2,
                                  alleles=NULL,
                                  sep="/",
                                  remove.spaces=TRUE,
                                  reorder=c("freq", "yes", "no",
                                    "default", "ascii"),
                                  allow.partial.missing=FALSE,
                                  markerNames,
                                  phase=list(F),
                                  ...
)
  {
    if (missing(gene.columns)) 
      gene.columns <- 1:ncol(x)
    else {
      nl <- as.list(1:ncol(x))
      names(nl) <- names(x)

      ## first eval any expressions to handle nifty things like " G1:G7 "
      gene.columns <-  eval(substitute(gene.columns), nl, parent.frame())

      ## now replace all column names with the corresponding column index
      charElem <- sapply(gene.columns,is.character)
      gene.columns[charElem] <- match(gene.columns[charElem], colnames(x))

      ## assume we have column indexes now...
      gene.columns <- as.numeric(gene.columns)
    }

    geneData <- subset(x, select=gene.columns, drop=FALSE)
    phenoData <- subset(x, select=-gene.columns, drop=FALSE)

    ## compute transtables and callcodes
    info <- makeCCodesAndTTables(data=geneData,
                                 format=format,
                                 ploidy=ploidy,
                                 alleles=alleles,
                                 sep=sep,
                                 remove.spaces=remove.spaces,
                                 reorder=reorder,
                                 allow.partial.missing=allow.partial.missing,
                                 markerNames=markerNames
                                 )

    codes <- info$callCodes
    transtables <- info$transTables
  
  
    markerInfo <- makeMarkerInfo(
                                 loci=names(info$transTables),
                                 transTable=names(transtables)
                                 )

    missingCodes <- list("ALL"= list(NA) )
    
    
    cs  <- geneSet(
                 callCodes = info$callCodes,
                 transTables = info$transTables,
                 sampleInfo = phenoData,
                 missingCodes = missingCodes,
                 notes = paste("Created by the call", match.call() ),
                 markerInfo = markerInfo,
                 phase = phase,
                 ploidy = ploidy,
                 studyInfo=list()
                 )

  cs
}
  
