# $Id: fastGrid.R 274 2005-07-03 02:50:30Z warnes $

fastGrid <- function(x) {
# DATE WRITTEN:  12 Nov 2004 		 LAST REVISED:  14 Jan 2005
# AUTHOR:  Scott D. Chasalow  (Scott.Chasalow <AT> bms.com)
#
# DESCRIPTION:
#       Creates a matrix giving all combinations of the elements of x.
#
# REQUIRED ARGUMENTS:
# x     a vector
#
# VALUE:
#       a matrix of the same mode as x, with dimension c(length(x)^2, 2). 
#       The rows give all points on a square lattice formed by pairing
#       every element of x with every element of x.  Here, order matters
#       - that is, (1, 2) and (2, 1) both would be included - and points
#       with an element taken twice - e.g. (1, 1) - also are included.
#
# SEE ALSO:
#       geneSet, expand.grid, fac.design, hcube
#
	if (is.null(x)) return(NULL)
	n <- length(x)
	if (n == 0)
		return(matrix(x, 0, 0))
	nseq <- seq(length = n)
	i1 <- rep.int(nseq, n)
	i2 <- rep.int(nseq, rep.int(n, n))
	cbind(x[i1], x[i2])
}
