##############
# Dr. Albert Vernon Smith made a great contribution to improve
# this file.
#
#Albert Vernon Smith, Ph.D.
#Cold Spring Harbor Laboratory
#HapMap Data Coordination Center
#E-mail: smithav@cshl.edu
#
##############

# In LdMax.cpp, the alleles need to be numbered sequentially up from one 
# Hence, we relabel the alleles.
#
# the most frequent allele is relabelled as allele 1
#
# genotypeMat -- n * (2*nMarkers) matrix
reLabelGenotypeMat<-function(genotypeMat)
{
  nrow<-nrow(genotypeMat)
  ncol<-ncol(genotypeMat)
  
  nMarkers<-ncol/2
  genotypeVec<-as.vector(genotypeMat) # stack column by column

  # stack two columns of a marker into one column
  genotypeMat2<-matrix(genotypeVec, ncol=nMarkers)

  tmp<-apply(genotypeMat2, 2, reLabelAlleles)
  
  tmp2<-as.vector(tmp)
  # retore to a 'nrow' by 'ncol' matrix
  res<-matrix(tmp2, ncol=ncol)
  return(res) 
}

# the most frequent allele is relabelled as allele 1
#
# genotype is a nx1 vector which stacks the two columns (loci) of alleles of 
# a marker 
# n is the number of subjects
reLabelAlleles<-function(genotype)
{
  genotypeVec<-as.vector(genotype)
  pos<-which(genotypeVec==0)
  genotypeVec2<-genotypeVec
  if(sum(pos)>0)
  { genotypeVec2<-genotypeVec2[-pos] }

  # get allele counts
  counts<-tapply(genotypeVec2, genotypeVec2, length)
  counts.s<-sort(counts, dec=TRUE)
  myla<-as.numeric(names(counts.s))
  
  len.u<-length(myla)

  genotypeVec3<-genotypeVec
  # the most frequent allele is relabelled as allele 1
  for(i in 1:len.u)
  {
    m<-myla[i]
    genotypeVec3[genotypeVec==m]<- i 
  }
  #genotype2<-matrix(genotypeVec3, ncol=2)
  genotype2<-genotypeVec3
  return(genotype2)
}

### get pair-wise LD measurment r^2  for founders of a ped matrix
getLD<-function(geneSetObj, pooling.threshold=0.1, founderOnly=FALSE, quiet=TRUE)
{
  foundersObj<-geneSetObj
  if(founderOnly)
  { foundersObj<-founderGeneSet(geneSetObj) }
  markerNames<-markerNames(foundersObj)
  nMarkers<-length(markerNames)

  founders<-geneSet2Ped(foundersObj)
  len<-length(founders$columns)
  founders<-founders$ped[,-c(1:len)]

  nr<-nrow(founders)
  nc<-ncol(founders)
  if(nc%%2)
  { stop("'founders' should have even number of columns! (note founders should not contain sample info columns)") }
  
  # the most frequent allele is relabelled as allele 1
  founders<-reLabelGenotypeMat(founders)

  founders<-as.integer(as.vector(t(founders)))
  nr<-as.integer(nr)
  nc<-as.integer(nc)
  pooling.threshold<-as.double(pooling.threshold)
  nMarkers<-as.integer(nMarkers)
  iprint<-as.integer(!quiet)
  
  tmpn<-(nMarkers-1)*nMarkers/2

  res<-.C("getLD", founders, nr, nc, nMarkers, pooling.threshold, 
    iprint, 
    rMat=as.double(rep(6, nMarkers*nMarkers)), 
    r2Mat=as.double(rep(6, nMarkers*nMarkers)), 
    DprimeMat=as.double(rep(6, nMarkers*nMarkers)), 
    DMat=as.double(rep(6, nMarkers*nMarkers)), 
    chisqMat=as.double(rep(-6, nMarkers*nMarkers)), 
    pvalMat=as.double(rep(6, nMarkers*nMarkers)), 
    nMat=as.integer(rep(-6, nMarkers*nMarkers)), 
    LODMat=as.double(rep(-6, nMarkers*nMarkers))) 

  pos<-which(res$rMat==6)
  if(length(pos)>0)
  { res$rMat[pos]<-NA }
  pos<-which(res$r2Mat==6)
  if(length(pos)>0)
  { res$r2Mat[pos]<-NA }
  pos<-which(res$DprimeMat==6)
  if(length(pos)>0)
  { res$DprimeMat[pos]<-NA }
  pos<-which(res$DMat==6)
  if(length(pos)>0)
  { res$DMat[pos]<-NA }
  pos<-which(res$chisqMat==-6)
  if(length(pos)>0)
  { res$chisqMat[pos]<-NA }
  pos<-which(res$pvalMat==6)
  if(length(pos)>0)
  { res$pvalMat[pos]<-NA }
  pos<-which(res$nMat==-6)
  if(length(pos)>0)
  { res$nMat[pos]<-NA }
  pos<-which(res$LODMat==-6)
  if(length(pos)>0)
  { res$LODMat[pos]<-NA }


  rMat<-matrix(res$rMat, nrow=nMarkers, ncol=nMarkers)
  r2Mat<-matrix(res$r2Mat, nrow=nMarkers, ncol=nMarkers)
  DprimeMat<-matrix(res$DprimeMat, nrow=nMarkers, ncol=nMarkers)
  DMat<-matrix(res$DMat, nrow=nMarkers, ncol=nMarkers)
  chisqMat<-matrix(res$chisqMat, nrow=nMarkers, ncol=nMarkers)
  pvalMat<-matrix(res$pvalMat, nrow=nMarkers, ncol=nMarkers)
  nMat<-matrix(res$nMat, nrow=nMarkers, ncol=nMarkers)
  LODMat<-matrix(res$LODMat, nrow=nMarkers, ncol=nMarkers)

  invisible(list(rMat=rMat, r2Mat=r2Mat, DprimeMat=DprimeMat, DMat=DMat, chisqMat=chisqMat, pvalMat=pvalMat, nMat=nMat,
                 LODMat=LODMat))
}


### get pair-wise LD measurment r^2  for founders of a ped matrix
getLDband<-function(geneSetObj, width=31, pooling.threshold=0.1, founderOnly=FALSE, quiet=TRUE)
{
  foundersObj<-geneSetObj
  if(founderOnly)
  { foundersObj<-founderGeneSet(geneSetObj) }

  markerNames<-markerNames(foundersObj)
  nMarkers<-length(markerNames)

  founders<-geneSet2Ped(foundersObj)
  len<-length(founders$columns)
  founders<-founders$ped[,-c(1:len)]

  nr<-nrow(founders)
  nc<-ncol(founders)
  if(nc%%2)
  { stop("'founders' should have even number of columns! (note founders should not contain sample info columns)") }

  if(!quiet)
  { cat("Number of founders=", nrow(founders), "\n")
    cat("Number of markers=", nMarkers, "\n")
  }

  # the most frequent allele is relabelled as allele 1
  founders<-reLabelGenotypeMat(founders)

  founders<-as.integer(as.vector(t(founders)))
  nr<-as.integer(nr)
  nc<-as.integer(nc)
  pooling.threshold<-as.double(pooling.threshold)
  nMarkers<-as.integer(nMarkers)
  iprint<-as.integer(!quiet)
  width<-as.integer(width)

  lag <- floor(width/2)
  lag<-as.integer(lag)
  
  tmpn<-(nMarkers-1)*nMarkers/2

  res<-.C("getLDband", founders, nr, nc, nMarkers, width, lag, 
    pooling.threshold, iprint, 
    rMat=as.double(rep(6, nMarkers*width)), 
    r2Mat=as.double(rep(6, nMarkers*width)), 
    DprimeMat=as.double(rep(6, nMarkers*width)), 
    DMat=as.double(rep(6, nMarkers*width)), 
    chisqMat=as.double(rep(-6, nMarkers*width)), 
    pvalMat=as.double(rep(6, nMarkers*width)), 
    nMat=as.integer(rep(-6, nMarkers*width)), 
    LODMat=as.double(rep(-6, nMarkers*width))) 

  pos<-which(res$rMat==6)
  if(length(pos)>0)
  { res$rMat[pos]<-NA }
  pos<-which(res$r2Mat==6)
  if(length(pos)>0)
  { res$r2Mat[pos]<-NA }
  pos<-which(res$DprimeMat==6)
  if(length(pos)>0)
  { res$DprimeMat[pos]<-NA }
  pos<-which(res$DMat==6)
  if(length(pos)>0)
  { res$DMat[pos]<-NA }
  pos<-which(res$chisqMat==-6)
  if(length(pos)>0)
  { res$chisqMat[pos]<-NA }
  pos<-which(res$pvalMat==6)
  if(length(pos)>0)
  { res$pvalMat[pos]<-NA }
  pos<-which(res$nMat==-6)
  if(length(pos)>0)
  { res$nMat[pos]<-NA }
  pos<-which(res$LODMat==-6)
  if(length(pos)>0)
  { res$LODMat[pos]<-NA }

  rMat<-matrix(res$rMat, nrow=nMarkers, ncol=width)
  r2Mat<-matrix(res$r2Mat, nrow=nMarkers, ncol=width)
  DprimeMat<-matrix(res$DprimeMat, nrow=nMarkers, ncol=width)
  DMat<-matrix(res$DMat, nrow=nMarkers, ncol=width)
  chisqMat<-matrix(res$chisqMat, nrow=nMarkers, ncol=width)
  pvalMat<-matrix(res$pvalMat, nrow=nMarkers, ncol=width)
  nMat<-matrix(res$nMat, nrow=nMarkers, ncol=width)
  LODMat<-matrix(res$LODMat, nrow=nMarkers, ncol=width)

  invisible(list(rMat=rMat, r2Mat=r2Mat, DprimeMat=DprimeMat, DMat=DMat, chisqMat=chisqMat, pvalMat=pvalMat, 
                 nMat=nMat, LODMat=LODMat))
}

getLDdist<-function(geneSetObj, posVec, maxDist, pooling.threshold=0.1, founderOnly=FALSE, quiet=TRUE)
{
  foundersObj<-geneSetObj
  if(founderOnly)
  { foundersObj<-founderGeneSet(geneSetObj) }
  markerNames<-markerNames(foundersObj)
  nMarkers<-length(markerNames)


  founders<-geneSet2Ped(foundersObj)
  len<-length(founders$columns)
  founders<-founders$ped[,-c(1:len)]

  nr<-nrow(founders)
  nc<-ncol(founders)
  if(nc%%2)
  { stop("'founders' should have even number of columns! (note founders should not contain sample info columns)") }

  if(!quiet)
  { cat("Number of founders=", nrow(founders), "\n")
    cat("Number of markers=", nMarkers, "\n")
  }

  # the most frequent allele is relabelled as allele 1
  founders<-reLabelGenotypeMat(founders)

  founders<-as.integer(as.vector(t(founders)))
  nr<-as.integer(nr)
  nc<-as.integer(nc)
  pooling.threshold<-as.double(pooling.threshold)
  nMarkers<-as.integer(nMarkers)
  iprint<-as.integer(!quiet)
  posVec<-as.integer(posVec)
  maxDist<-as.integer(maxDist)
  
  tmpn<-(nMarkers-1)*nMarkers/2

  res<-.C("getLDdist", founders, nr, nc, nMarkers, posVec, maxDist,
    pooling.threshold, iprint, 
    rMat=as.double(rep(6, nMarkers*nMarkers)), 
    r2Mat=as.double(rep(6, nMarkers*nMarkers)), 
    DprimeMat=as.double(rep(6, nMarkers*nMarkers)), 
    DMat=as.double(rep(6, nMarkers*nMarkers)), 
    chisqMat=as.double(rep(-6, nMarkers*nMarkers)), 
    pvalMat=as.double(rep(6, nMarkers*nMarkers)), 
    nMat=as.integer(rep(-6, nMarkers*nMarkers)), 
    LODMat=as.double(rep(-6, nMarkers*nMarkers))) 

  pos<-which(res$rMat==6)
  if(length(pos)>0)
  { res$rMat[pos]<-NA }
  pos<-which(res$r2Mat==6)
  if(length(pos)>0)
  { res$r2Mat[pos]<-NA }
  pos<-which(res$DprimeMat==6)
  if(length(pos)>0)
  { res$DprimeMat[pos]<-NA }
  pos<-which(res$DMat==6)
  if(length(pos)>0)
  { res$DMat[pos]<-NA }
  pos<-which(res$chisqMat==-6)
  if(length(pos)>0)
  { res$chisqMat[pos]<-NA }
  pos<-which(res$pvalMat==6)
  if(length(pos)>0)
  { res$pvalMat[pos]<-NA }
  pos<-which(res$nMat==-6)
  if(length(pos)>0)
  { res$nMat[pos]<-NA }
  pos<-which(res$LODMat==-6)
  if(length(pos)>0)
  { res$LODMat[pos]<-NA }


  rMat<-matrix(res$rMat, nrow=nMarkers, ncol=nMarkers)
  r2Mat<-matrix(res$r2Mat, nrow=nMarkers, ncol=nMarkers)
  DprimeMat<-matrix(res$DprimeMat, nrow=nMarkers, ncol=nMarkers)
  DMat<-matrix(res$DMat, nrow=nMarkers, ncol=nMarkers)
  chisqMat<-matrix(res$chisqMat, nrow=nMarkers, ncol=nMarkers)
  pvalMat<-matrix(res$pvalMat, nrow=nMarkers, ncol=nMarkers)
  nMat<-matrix(res$nMat, nrow=nMarkers, ncol=nMarkers)
  LODMat<-matrix(res$LODMat, nrow=nMarkers, ncol=nMarkers)

  invisible(list(rMat=rMat, r2Mat=r2Mat, DprimeMat=DprimeMat, DMat=DMat, chisqMat=chisqMat, pvalMat=pvalMat, nMat=nMat,
                 LODMat=LODMat))
}


