# $Id: markerSummary.R 1068 2006-11-10 08:41:14Z warnes $

markerSummary <- function(object,
                          covariate=NULL,
                          confidence=0.95,
                          alpha=1-confidence,
                          show=TRUE,
                          ...)
  {
    retval <- list()

    retval$alleleSummary <- alleleSummary(object,
                                          covariate=covariate,
                                          confidence=confidence,
                                          alpha=alpha,
                                          show=show,
                                          ...)
    retval$genotypeSummary <- genotypeSummary(object,
                                          covariate=covariate,
                                          confidence=confidence,
                                          alpha=alpha,
                                          show=show,
                                          ...)

    retval$LD <- LD(object,...)

    retval$call <- match.call()
    class(retval) <- "markerSummary"
    
    retval
  }


print.markerSummary <- function(x, ...)
  {

        ## Print Allele Summary
        cat("--------------\n")
        cat("Allele Summary\n")
        cat("--------------\n")
        cat("\n")

        print(x$alleleSummary)

        cat("\n\n")
        
        ## Print Genotype Summary
        cat("----------------\n")
        cat("Genotype Summary\n")
        cat("----------------\n")
        cat("\n")

        print(x$genotypeSummary)
        
        ## Print LD Summary
        print(x$LD)

        ## Plot LD
        plot(x$LD)
  }

write.markerSummary <- function(x, filename="", plot.format="pdf",
                               sep=".", verbose=TRUE, ..., format="html")
  {
    FUN <- get(format, mode="function")
    if(format=="latex") format="tex"

    ## alleleSummary
    if(filename!="")
      {
        filename.a <- paste(filename,
                            paste("alleleSummary",format, sep="."),
                            sep=sep)
        if(verbose)
          cat("Creating ", filename.a, "...\n")
      }
    else
      filename.a <- ""
    
    FUN(x$alleleSummary, filename=filename.a, ...)

    ## genotypeSummary
    if(filename!="")
      {
        filename.g <- paste(filename,
                            paste("genotypeSummary", format, sep="."),
                            sep=sep)
        if(verbose)
          cat("Creating ", filename.g, "...\n")
      }
    else
      filename.g <- ""

    FUN(x$genotypeSummary, filename=filename.g, ...)

    ## LD table 
    if(filename!="")
      {
        filename.l <- paste(filename,
                            paste("LD", format, sep="."),
                            sep=sep)
        if(verbose)
          cat("Creating ", filename.l, "...\n")
      }
    else
      filename.l <- ""

    FUN(x$LD, filename=filename.l, ...) 

    ## LD plot
    if(filename!="")
      {
        filename.p <- paste(filename,
                            paste("LD.", plot.format,  sep=''),
                            sep=sep)
        if(plot.format=="pdf")
          pdf(file=filename.p)
        else
          stop("unsupported format")
        if(verbose)
          cat("Creating ", filename.p, "...\n")
      }
    else
      filename.p <- "LD.pdf"


    plot.LD(x$LD)
    
    if(filename!="")
      dev.off()

    if(filename!="" && verbose)
      cat("Done.\n")
  }

# wrappers
txt.markerSummary <- function(x, filename="", plot.format="pdf",
                              sep=".", verbose=TRUE, ...)
  {
    write.markerSummary(x=x, filename=filename, plot.format=plot.format,
                        sep=sep, verbose=verbose, ..., format="txt")
  }

html.markerSummary <- function(x, filename="", plot.format="pdf",
                              sep=".", verbose=TRUE, ...)
  {
    write.markerSummary(x=x, filename=filename, plot.format=plot.format,
                        sep=sep, verbose=verbose, ..., format="html")
  }

latex.markerSummary <- function(x, filename="", plot.format="pdf",
                              sep=".", verbose=TRUE, ...)
  {
    write.markerSummary(x=x, filename=filename, plot.format=plot.format,
                        sep=sep, verbose=verbose, ..., format="latex")
  }

