read.phe <- function(
                     filename,
                     columns=c("family","pid"),
                     quiet=FALSE,
                     ...
                     )
{
  ## pedigree file format
  ## --------------------
  ##
  ## line 1         : names of phenotype variables (1 to p)
  ## line 2 to (N+1):  <family> <pid> <var1> <var2> ... <var_p>
  ##
  ## <family> is a unique identifier for each family, and within each family
  ## <pid> is a unique identifier for an individual.
  ##

  ## first line of file gives marker names
  vars <- scan(file=filename, what="", nlines=1, quiet=TRUE)
  if(!quiet)
    cat("\nReading ", length(vars), " vars from `", filename, "' ... ",
        sep='')

  ## Add these to the other columns
  colNames <- c(columns, vars)

  ## And read in
  #tab <- read.table(filename,sep=' ', header=F, skip=1,
  #                  col.names = colNames,
  #                  colClasses = "numeric"
  #                  )
  
  tab <- matrix( scan(file=filename, sep=' ', what=numeric(1), skip=1,
                      quiet=TRUE, na.strings="-", ...),
                byrow=TRUE, ncol=length(colNames) )
  colnames(tab) <- colNames

  if(!quiet)
    {
      cat("Done.\n")

      cat("\n")
      cat("Number of Phenotype Variables:", length(vars), "\n")
      cat("Number of Observations       :", nrow(tab), "\n")
      cat("\n")
    }

  return(data.frame(tab))
}

read.fbat.phe <- read.phe
read.pbat.phe <- read.phe
