readGenes.pfizer <- function(filename,
                             phase=list(F),
                             format=c("Pivot","Listing"),
                             ...)
{
  format <- match.arg(format)

  ## use helper funtions to load file data
  dataList <- switch(format,
                     Pivot=read.pfizer.Pivot(filename),
                     Listing=read.pfizer.Listing(filename)
                     )

  ## compute transtables and callcodes
  info <- makeCCodesAndTTables(data=dataList$genotypeInfo,
                               format="single",
                               ploidy=2,
                               reorder="freq"
                               )

  codes <- info$callCodes
  transtables <- info$transTables
  
  
  markerInfo <- cbind(
                      makeMarkerInfo(
                                     loci=names(info$transTables),
                                     transTable=names(transtables)
                                     ),
                      dataList$markerInfo
                      )

  missingCodes <- list("ALL"= list(NA) )

  
  cs  <- geneSet(
                 callCodes = info$callCodes,
                 transTables = info$transTables,
                 sampleInfo = dataList$phenotypeInfo,
                 missingCodes = missingCodes,
                 notes = paste("Loaded from file `", filename, "'.", sep=""),
                 markerInfo = markerInfo,
                 phase = phase,
                 ploidy = 2,
                 studyInfo=dataList$studyInfo
                 )

  cs
}
