readGenes.perlegen <- function(filename, ..., quiet=FALSE)
{
  if(!quiet)
    cat("Loading file... ")
  
  dat <- scan(filename, skip=1,
              what=list(character(1),character(1)),
              ..., quiet=TRUE)

  cat("done.\n")
  
  names(dat) <- c("snp.id","genotype")

  nobs <- nchar(dat$genotype[1])
  nmarker <- length(dat$snp.id) 

  if(!quiet)
    {
      cat("\n")
      cat("Number of markers     :", nmarker, "\n")
      cat("Number of observations:", nobs, "\n"  )
      cat("\n")
    }
            
            
  marker.levels <- c("r","h","a")
  transtables <- list("SNP"=cbind(levels=c("r/r","r/a","a/a"),
                                  allele.1=c("r","r","a"),
                                  allele.2=c("r","a","a") ))
  misscodes <- list(SNP="NA")
  
  ## First create the object, that way we don't get as many copies
  ## of the (Very large) callCodes object.
  cs  <- new('geneSet',
             #callCodes = codes, # add below to avoid extra copy
             transTables = transtables,
             sampleInfo = data.frame(id=1:nobs),
             missingCodes = misscodes,
             notes = paste("Loaded from file `", filename, "'.", sep=''),
             #markerInfo = markerInfo, # add below 
             #phase = phase, 
             ploidy = 2)

  cs@callCodes <- convert( dat$genotype, levels=marker.levels, byrow=T)
  
  colnames(cs@callCodes) <- paste("obs",1:ncol(cs@callCodes))
  rownames(cs@callCodes) <- dat$snp.id

  cs@markerInfo <- makeMarkerInfo(
                                  loci=dat$snp.id,
                                  transTable=rep("SNP", length(dat$snp.id))
                                  )

  rm(dat) 

  validate(cs) # ensure proper structure
  cs
}
