\name{decodeCallCodes}
\alias{decodeCallCodes}
\title{
Converts integer codes in a callCodes matrix to character string
      representations of geneSet.
}
\description{
Converts integer codes in a callCodes matrix to character string
      representations of geneSet.
}
\usage{
decodeCallCodes(callCodes, transTables, markerInfo)
}
\arguments{
  \item{callCodes}{
 matrix of positive integers, such as the callCodes slot of
       a geneSet object.
}
  \item{transTables}{ 
list of code translation tables, such as the transTables
       slot of a geneSet object.
}
  \item{markerInfo}{ 
 dataframe, with one row for each row in the callCodes
       matrix, such as the markerInfo slot of a geneSet object.
       Must include at least column "TransTable".
}
}
\details{
}
\value{
 a character matrix with the same dimension and dimnames as
       argument callCodes, giving character string representations of
       genotypes, as specified by a set of translation tables.
}
\author{Scott D. Chasalow}
\seealso{ geneSet}
\examples{
library(GeneticsBase)
tTabList <- makeTransTableList(c("Bb", "ATG"), c("Generic", "SNP"))
locus <- c("c104t", "c2249t")
ttab <- c("SNP", "Generic")
minfo <- makeMarkerInfo(locus, ttab)
misscodes <- list(Generic = c("NA", ".", "-"), SNP = "N")
r1 <- c(1, 2, 1, 1)
r2 <- c(1, 2, 3, 2)
data <- rbind(r1, r2) # callCodes
dimnames(data) <- list(locus, paste("Sample", seq(along = r1),
        sep = "."))
decodeCallCodes(data, tTabList, minfo)
}
\keyword{misc} 
