\name{geneSet-class}
\docType{class}
\alias{geneSet-class}
\alias{geneSet}
\alias{HWE,geneSet-method}
\alias{LD,geneSet-method}
\alias{LDband,geneSet-method}
\alias{LDdist,geneSet-method}
\alias{[,geneSet-method}
\alias{[[,geneSet-method}
\alias{alleleCount,geneSet-method}
\alias{alleleLevels,geneSet-method}
\alias{alleles,geneSet-method}
\alias{callCodes,geneSet-method}
\alias{callCodes<-,geneSet-method}
\alias{carrier,geneSet-method}
\alias{description,geneSet-method}
\alias{description<-,geneSet-method}
\alias{dominant,geneSet-method}
\alias{errorMetrics,geneSet-method}
\alias{errorMetrics<-,geneSet-method}
\alias{genotypeLevels,geneSet-method}
\alias{genotypes,geneSet-method}
\alias{head,geneSet-method}
\alias{heterozygote,geneSet-method}
\alias{homozygote,geneSet-method}
\alias{markerInfo,geneSet-method}
\alias{markerInfo<-,geneSet-method}
\alias{markerNames,geneSet-method}
\alias{missingCodes,geneSet-method}
\alias{missingCodes<-,geneSet-method}
\alias{nallele,geneSet-method}
\alias{nmarker,geneSet-method}
\alias{nobs,geneSet-method}
\alias{notes,geneSet-method}
\alias{notes<-,geneSet-method}
\alias{phase,geneSet-method}
\alias{phase<-,geneSet-method}
\alias{ploidy,geneSet-method}
\alias{ploidy<-,geneSet-method}
\alias{recessive,geneSet-method}
\alias{sampleInfo,geneSet-method}
\alias{sampleInfo<-,geneSet-method}
\alias{show,geneSet-method}
\alias{studyInfo,geneSet-method}
\alias{studyInfo<-,geneSet-method}
\alias{tail,geneSet-method}
\alias{transTables,geneSet-method}
\alias{transTables<-,geneSet-method}

\title{Class "geneSet", a class for genetics data}
\description{
A fundamental data structure for genetic data
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("geneSet", ...)}.
	 ~~ describe objects here ~~ 
}
\section{Slots}{
  \describe{
    \item{\code{callCodes}:}{matrix of positive integers, 
       giving genotype calls.  Each row is a locus (marker); 
       each column is an individual (sample).  Each element 
       is a row index into a matrix in the list of translation 
       tables stored in the transTables slot.  Must have row 
       and column names.
     }
     \item{\code{errorMetrics}:}{numeric matrix, parallel to the 
       callCodes matrix.  Each element gives an uncertainty measure 
       for the corresponding element of the callCodes matrix.  Must 
       have row and column names.
     }
     \item{\code{transTables}:}{list of code translation tables.  The 
       list must have names.  Each component is a matrix, and must 
       include a column named "levels".
     }
     \item{\code{missingCodes}:}{list of allele missing-value codes, 
       parallel to the transTables list.  The list must have the same 
       names as the list in the transTables slot.  Each component is 
       a character vector.  Any allele symbol in component "abc" of 
       the transTables list that appears in component "abc" of the 
       missingCodes list is to be interpreted as a missing value by 
       functions operating on the geneSet object. An empty list will be 
       interpreted to mean that the data contains no missing values.
     }
     \item{\code{sampleInfo}:}{Object of class \code{"data.frame"} }
     \item{\code{markerInfo}:}{a dataframe, with one row for each row 
       in the callCodes matrix.  Must include columns "Name" and 
       "TransTable".  
     }
     \item{\code{studyInfo}:}{Object of class \code{"list"} ~~ }
     \item{\code{description}:}{Object of class \code{"character"} ~~ }
     \item{\code{notes}:}{Object of class \code{"character"} ~~ }
     \item{\code{ploidy}:}{Object of class \code{"numeric"} ~~ }
     \item{\code{phase}:}{ 
        1. Yes/No for all (logical scalar)
        2. Yes/No for each Marker (logical vector)
        3. phaseObject (TBD): observation by marker by phase
           probabilities + definitions of contigs + probability of
           contigs 
     }
   }
}
\section{Methods}{
  \describe{
    \item{HWE}{\code{signature(object = "geneSet")}: Hardy-Weinberg Equilibrium Significance Test }
    \item{LD}{\code{signature(object = "geneSet")}: ... }
    \item{LDband}{\code{signature(object = "geneSet")}: ... }
    \item{LDdist}{\code{signature(object = "geneSet")}: ... }
    \item{[}{\code{signature(x = "geneSet")}: ... }
    \item{[[}{\code{signature(x = "geneSet")}: ... }
    \item{alleleCount}{\code{signature(object = "geneSet")}: ... }
    \item{alleleLevels}{\code{signature(object = "geneSet")}: ... }
    \item{alleles}{\code{signature(object = "geneSet")}: ... }
    \item{callCodes}{\code{signature(object = "geneSet")}: ... }
    \item{callCodes<-}{\code{signature(object = "geneSet")}: ... }
    \item{carrier}{\code{signature(object = "geneSet")}: ... }
    \item{description}{\code{signature(object = "geneSet")}: ... }
    \item{description<-}{\code{signature(object = "geneSet")}: ... }
    \item{dominant}{\code{signature(object = "geneSet")}: ... }
    \item{errorMetrics}{\code{signature(object = "geneSet")}: ... }
    \item{errorMetrics<-}{\code{signature(object = "geneSet")}: ... }
    \item{genotypeLevels}{\code{signature(object = "geneSet")}: ... }
    \item{genotypes}{\code{signature(object = "geneSet")}: ... }
    \item{head}{\code{signature(x = "geneSet")}: ... }
    \item{heterozygote}{\code{signature(object = "geneSet")}: ... }
    \item{homozygote}{\code{signature(object = "geneSet")}: ... }
    \item{markerInfo}{\code{signature(object = "geneSet")}: ... }
    \item{markerInfo<-}{\code{signature(object = "geneSet")}: ... }
    \item{markerNames}{\code{signature(object = "geneSet")}: ... }
    \item{missingCodes}{\code{signature(object = "geneSet")}: ... }
    \item{missingCodes<-}{\code{signature(object = "geneSet")}: ... }
    \item{nallele}{\code{signature(object = "geneSet")}: ... }
    \item{nmarker}{\code{signature(object = "geneSet")}: ... }
    \item{nobs}{\code{signature(x = "geneSet")}: ... }
    \item{notes}{\code{signature(object = "geneSet")}: ... }
    \item{notes<-}{\code{signature(object = "geneSet")}: ... }
    \item{phase}{\code{signature(object = "geneSet")}: ... }
    \item{phase<-}{\code{signature(object = "geneSet")}: ... }
    \item{ploidy}{\code{signature(object = "geneSet")}: ... }
    \item{ploidy<-}{\code{signature(object = "geneSet")}: ... }
    \item{recessive}{\code{signature(object = "geneSet")}: ... }
    \item{sampleInfo}{\code{signature(object = "geneSet")}: ... }
    \item{sampleInfo<-}{\code{signature(object = "geneSet")}: ... }
    \item{show}{\code{signature(object = "geneSet")}: ... }
    \item{studyInfo}{\code{signature(object = "geneSet")}: ... }
    \item{studyInfo<-}{\code{signature(object = "geneSet")}: ... }
    \item{tail}{\code{signature(x = "geneSet")}: ... }
    \item{transTables}{\code{signature(object = "geneSet")}: ... }
    \item{transTables<-}{\code{signature(object = "geneSet")}: ... }
	 }
}
\references{ ~put references to the literature/web site here ~ }
\author{ 
        J.Cheng, modified by S. Chasalow, and
      Gregory R. Warnes <warnes@bst.rochester.edu>
}
\note{ ~~further notes~~ }
\seealso{
}
\examples{
##---- Should be DIRECTLY executable !! ----
}
\keyword{classes}
