\name{html}
\alias{html}
\alias{html.LD}
\alias{html.markerSummary}
\alias{html.GeneticsBaseSummary}

\alias{txt}
\alias{txt.default}
\alias{txt.LD}
\alias{txt.markerSummary}
\alias{txt.GeneticsBaseSummary}
\alias{print.GeneticsBaseSummary}

\alias{latex}
\alias{latex.default}
\alias{latex.LD}
\alias{latex.markerSummary}
\alias{latex.GeneticsBaseSummary}
\title{Generate summary table files for genotype objects}
\description{
  Generate summary table files for genotype objects
}
\usage{
#### HTML file format
html
\method{html}{LD}(x, filename = "", digits = 3, ...)
\method{html}{GeneticsBaseSummary}(x, filename = "", ...)
\method{html}{markerSummary}(x, filename = "", plot.format = "pdf", 
                   sep=".", verbose=TRUE, ...)

#### plain text file format
txt
\method{txt}{default}(x, filename="", eol="\n", ...)
%\method{txt}{LD}(x, filename = "", digits = 3, ...)
%\method{txt}{GeneticsBaseSummary}(x, filename = "", ...)
\method{txt}{markerSummary}(x, filename = "", plot.format = "pdf",
                   sep=".", verbose=TRUE, ...)

#### LaTex file format
latex
\method{latex}{default}(x, filename="", ...)
\method{latex}{LD}(x, filename = "", digits = 3, ...)
\method{latex}{GeneticsBaseSummary}(x, filename = "", ...)
\method{latex}{markerSummary}(x, filename = "", plot.format = "pdf",
                   sep=".", verbose=TRUE, ...)

}
\arguments{
  \item{x}{Object to be rendered to html/txt/latex}
  \item{filename}{Output filename, see below for details.}
  \item{eol}{End of line marker, defaults to \code{"\n"}. MS-DOS/MS-Windows
    uses \code{"\r\n"} }
  \item{digits}{Number of digits to display}
  \item{plot.format}{Graphics format for LD plot. Only \code{"pdf"} is
    currently supported}
  \item{sep}{Separatior used to join the file prefix provided by
    \code{filename} and descriptive text when generating file names}
  \item{verbose}{Show names of created files.} 
  \item{\dots}{Additional parameters to pass to component methods}
}
\details{
  For \code{alleleSummary}, \code{genotypeSummary}, and \code{LD}
  objects, the \code{filename} argument is either the exact name of the file to
  be created, or "" which will print the output to the console.

  For \code{markerSummary} objects, \code{filename} may be either
  \code{""} or a prefix used to create file names. If \code{filename=""}
  all output is printed to the R console.  Otherwise, filenames for each
  component are constructed by combining the prefix specified by
  \code{filename}, the separator specified by \code{sep}, a string
  descibing the file contents (one of "alleleSummary",
  "genotypeSummary", and "LD"), and the file extension ".html".
}
\value{
  Nothing of interest
}
\author{
  Nitin Jain \email{nitin\_jain@pfizer.com} and
  Gregory R. Warnes \email{warnes@bst.rochester.edu}
}
\seealso{
  \code{\link{alleleSummary}},
  \code{\link{genotypeSummary}},
  \code{\link{markerSummary}},
  \code{\link{LD}}
}
\examples{
data(CAMP)

###
# Generate a plain text allele summary table
###
aS <- alleleSummary(CAMP)
# display inline
txt(aS, filename="")
# create CAMP_alleleSummary.txt
txt(aS, filename="CAMP.alleleSummary.html") 

###
# Generate an HTML genotype summary table
###
gS <- genotypeSummary(CAMP)
# display inline
html(gS, filename="")
# create CAMP_genotypeSummary.html
html(gS, filename="CAMP.genotypeSummary.html")

###
# Generate a LaTeX Linkage Disequilibrium table
###
ld <- LD(CAMP)
# display inline
latex(ld, filename="")
# create CAMP_LDSummary.html
latex(ld, filename="CAMP.LD.html")

###
# Generate a complete set of summary tables 
###
mS <- markerSummary(CAMP)
# Plain text format
txt(mS, filename="CAMP", sep="_")
# HTML format
html(mS, filename="CAMP", sep="_")
# LaTeX format
latex(mS, filename="CAMP", sep="_")

}
\keyword{ misc}
