% $Id: print.LD.Rd 1069 2006-11-10 08:43:19Z warnes $
\name{plot.LD}
\alias{plot.LD}
\alias{plot}
\alias{LDView}
\title{Textual and graphical display of linkage disequilibrium (LD) objects}
\description{
  Textual and graphical display of linkage disequilibrium (LD) objects
}
\usage{
plot(x, y, ...)
plot.LD (x, y=NULL, cex, ...)
LDView(LdMat,
       SNPloc=NULL,
       is.triangle=TRUE,
       SNPnames=NULL,
       cexSNPnames=0.2+1/log10(nrow(LdMat)),
       margins=c(6,2,3,6),
       main=NULL,
       barCol=rainbow(256,start=0,end=1/6 ),
       widths=c(10,10),
       heights=c(1,10),
       ...)

% plot.geneSet(x, digits=3, colorcut=c(0,0.01, 0.025, 0.5, 0.1, 1),
%     colors=heat.colors(length(colorcut)), textcol="black",
%     marker, which="D'", distance,  ...)



}
\arguments{
  \item{x}{LD or LDband object}
  \item{y}{ currently ignored}
  \item{cex}{Scaling factor for table text. If absent, text will be
    scaled to fit within the table cells.}
  \item{LdMat}{matrix of pair-wise LD measures}
  \item{SNPloc}{SNP locations}
  \item{is.triangle}{indicate if 'LdMat' is a lower triangle matrix or not.
               if 'LdMat' is an upper triangle, then the user has to
               transpose it before calling the function 'LDView'.}
  \item{SNPnames}{labels for SNPs}
  \item{cexSNPnames}{font size for SNPs labels}
  \item{margins}{margins for heatmap}
  \item{main}{title for the plot}
  \item{barCol}{specify the color scheme}
  \item{widths}{The plot is split into two parts -- upper part and lower part
            'widths' specifies the widths of the two parts}
  \item{heights}{The plot is split into two parts -- upper part and lower part
            'heights' specifies the heights of the two parts}
  \item{\dots}{Optional arguments (\code{plot.LD.data.frame} passes
    these to \code{LDtable} and \code{LDplot}) and other parameters for the function 'image'}
}
\details{

  LDtable generates a graphical matrix of LD coefficients.  It attempts
  to properly set the font size so that the estimated values fit into
  the boxes.  It also colorized the boxes to whether the estimates are
  significantly different from no linkage.

  LDplot generates a plot of the LD coeffients across markers.  By
  default it will overlay plots for LD against all markers.  LD against a
  specific subset of markers can be obtained using the \code{marker}
  argument.
  
}
\value{
  \item{SNPnames}{labels of the SNPs in \code{LDView}}
  \item{LdMat}{LD matrix}
  \item{SNPloc}{SNP positions}
}
%\references{ ~put references to the literature/web site here ~ }
\author{ Gregory R. Warnes \email{warnes@bst.rochester.edu} }
\seealso{ \code{LD}, \code{geneSet}, \code{diseq} }
\examples{

# load the data
data(CAMP)

# compute pairwise LD
ld <- LD(CAMP)

print(ld)    # text display of LD coefficents and graphical display of LD estimates

LDView(t(ld@"R^2"), SNPloc=1:8, SNPnames=CAMP@markerInfo$Name)


## LDtable(ld) # graphical display of LD estimates
## LDtable(ld, which="D'", digits=2) # graphical display of D' only 


## plot(CAMP) # two panel display

}
\keyword{misc}

