//////////////////////////////////////////////////////////////////////
// LdMax.h
// (c) 2000-2001 Goncalo Abecasis (goncalo@umich.edu)
//
// This file was derived with kind permission from the original author (Dr Abecasis),
// from material distributed as part of the GOLD (Bioinformatics 16:182-3, 2000)
// source code package which is available in it's original form from
// http://www.sph.umich.edu/csg/abecasis/GOLD/
//
// If this library proves useful to you, please ensure the original source is properly
// attributed using the citation above.
//
// This library is free software; you can redistribute it and/or modify it under the terms of the
// GNU Lesser General Public License as published by the Free Software Foundation; either version
// 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
// even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License along with this library;
// if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
// 02111-1307 USA or try http://www.opensource.org/licenses/lgpl-license.php
//
// Please contact the project maintainers responsible for the distribution of this library for
// technical support, not the author.
//
// To request permission to use this source code library other than under the LGPL, please
// contact the copyright holder, Dr Abecasis directly at goncalo@umich.edu
// original header follows:
////////////////////////////////////////////////////////////////////////
// ldmax/LdMax.h
// (c) 2000-2001 Goncalo Abecasis
//
// This file is distributed as part of the GOLD source code package
// and may not be redistributed in any form, without prior written
// permission from the author. Permission is granted for you to
// modify this file for your own personal use, but modified versions
// must retain this copyright notice and must not be distributed.
//
// Permission is granted for you to use this file to compile GOLD.
//
// All computer programs have bugs. Use this file at your own risk.
//
// Thursday November 08, 2001
//
/**************
*
* GOLD source code reference
*
* @article{AbecasisCookson:2000,
*   author="{Abecasis, G. R.} and {Cookson, W. O. C.}",
*   title={{GOLD} --- Graphical Overview of Linkage Disequilibrium},
*   journal={Bioinformatics},
*   volume={16},
*   pages={182-183},
*   year={2000}
* }
*
*
***************/

/****************
 Dr. Albert Vernon Smith made a great contribution to improve
 this file.

Albert Vernon Smith, Ph.D.
Cold Spring Harbor Laboratory
HapMap Data Coordination Center
E-mail: smithav@cshl.edu

****************/

#ifndef __LDMAX_H__
#define __LDMAX_H__

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<stdarg.h>

#include <R.h>


#define TOL     1.0e-6         // Zero SVD values bellow this
#define TINY    1.0e-30        // A small number
#define FPMIN   1.0e-30        // Number near the smallest representable number
#define ITMAX   100            // Maximum number of iterations
#define EPS     3.0e-7         // Relative accuracy

#ifndef _ERROR_H_
#define _ERROR_H_

#ifdef __cplusplus
extern "C" {
#endif

#ifdef __cplusplus
   };
#endif


#endif


inline int mymin(int a, int b)  { return (a) < (b) ? (a) : (b); }
inline double mymind(double a, double b)  { return (a) < (b) ? (a) : (b); }
inline int mymax(int a, int b)  { return (a) > (b) ? (a) : (b); }
inline double mymaxd(double a, double b)  { return (a) > (b) ? (a) : (b); }

double chidist(double x, double v);
double gammq ( double a, double x );
void gser ( double * gamser, double a, double x, double * gln);
void gcf ( double * gammcf, double a, double x, double * gln);
double gammln ( double xx );
extern "C" {
void getLD(int *founders, int *nrow, int *ncol,  int *numMarkers, double *pool, 
		int *iprint, double *rMat, double *r2Mat, double *DprimeMat, 
		double *DMat, double *chisqMat, double *pvalMat, int *nMat, double *LODMat);
}

extern "C" {
void getLDband(int *founders, int *nrow, int *ncol,  int *numMarkers, 
		int *width, int *lag, double *pool, 
		int *iprint, double *rMat, double *r2Mat, double *DprimeMat, 
		double *DMat, double *chisqMat, double *pvalMat, int *nMat, double *LODMat);
}

extern "C" {    
void getLDdist(int *founders, int *nrow, int *ncol,  int *numMarkers, int *pos,
                int *maxDist, double *pool, int *iprint, double *rMat,
                double *r2Mat, double *DprimeMat, double *DMat,
                double *chisqMat, double *pvalMat, int *nMat, double *LODMat);
}


class LDMax
   {
   public:

      double   ** alleleFrequencies, * haplotypeFrequencies, * genotypeFrequencies;
      int ** haplotypeList1, ** haplotypeList2, * lenHaploLists;
      int * haplotype1, * haplotype2, * genotype, * genotypeCounts;
      int * markers;
      int * nAlleles, * nGenotypes;
     
      int  foundersOnly;
      int  nloci;
      long nhaplo, ngeno, count;

      LDMax();
      ~LDMax();

      bool SelectMarkers(int * markers, int *ped, int nrow, int ncol,
		      int n_loci);
      int CountAlleles(int marker, int *ped, int nrow, int ncol);
      void LumpAlleles(int *ped, int nrow, int ncol, double threshold, 
		int marker);

      bool isGenotyped(int *ped, int ncol, int p);
      void GetGenotype(int *ped, int ncol, int p);
      void GetGenotype();

      int  GenotypeIndex();
      int  HaplotypeIndex(int * haplo);

      void   ResetHaplotype(int * haplo);
      bool   isLastHaplotype(int * haplo);
      bool   IncrementHaplotype(int * haplo);
      void   AppendHaploList(int ** haplo_list, int value, int old_len);

      void   GetHaplotype(int * haplo, int number);
      double NullFreq(int * haplo);
      void   NullFrequencies();

      void   UpdateGenotypeFrequencies();
      void   UpdateHaplotypeFrequencies();

      double LogLikelihood();
      void   Maximize();

      // Useful summaries
      double  * defaults, * estimates;

      double logLKfull, logLKnull, ChiSq, pvalue, LOD, Dprime, D, deltasq, delta;
      int    dfNull, dfFull;

      void TheWorks();

   private:
  
       void NullWorkingArrays();
       void FreeWorkingArrays();

       void NewIntArray(int ** target, int dim, int value = 0);
       void NewVector(double ** target, int dim, double value = 0.0);
    
       void CopyVector(double ** target, double * source, int dim);
       void CopyIntArray(int ** target, int * source, int dim);

   };

#endif

