//#include "bitArrayVector.hpp"

#include <iostream>
#include <sstream>
#include <vector>
#include <bitset>
#include <iterator>

#include <R.h>
#include <Rdefines.h>
#include <Rinternals.h>


using namespace std;


static SEXP  bitArrayVector_tag;

extern "C" {
SEXP bitArrayVector_init(void)
{
  bitArrayVector_tag = install("BITARRAYVECTOR_TYPE_TAG");
  return R_NilValue;
}
}

// Finalizer 
extern "C" {
  SEXP finalizeBitArrayVector(SEXP objptr)
  {
    cout << "bv destructor" << endl;

    vector<bool> *pbv = (vector<bool>*) R_ExternalPtrAddr(objptr);
    delete pbv;

  }
}


// Constructor
extern "C" {
SEXP bitArrayVector(SEXP R_nbits, SEXP R_length)
{
  SEXP retObj, i_nbits, i_length;
  PROTECT(i_nbits  = AS_INTEGER(R_nbits));
  PROTECT(i_length = AS_INTEGER(R_length));

  int nbits  = INTEGER(i_nbits)[0];
  int length = INTEGER(i_length)[0];
   
  cout << "nbits = " << nbits << endl;
  cout << "length = " << length << endl;

  vector<bool> *pbv = new vector<bool>( nbits*length  , false );

  cout << "size = " << pbv->size() << endl;

  PROTECT(retObj = R_MakeExternalPtr( (void*) pbv, bitArrayVector_tag, R_NilValue ));
	    
  R_RegisterCFinalizer(retObj, (R_CFinalizer_t) finalizeBitArrayVector);

  UNPROTECT(3);

  cout << "bv*" << pbv << endl;
  cout << "size = " << pbv->size() << endl;

  return(retObj);
}
} 

extern "C" {
SEXP bitArrayVector_length(SEXP rbv)
{
  vector<bool> *pbv = (vector<bool> *) R_ExternalPtrAddr(rbv);
  SEXP tag = R_ExternalPtrTag(rbv);

  if(tag != bitArrayVector_tag)
    error("Argument is not of class bitArrayVector");
      
  cout << "bv*" << pbv << endl;
  cout << "size = " << pbv->size() << endl;

  SEXP ans;
  PROTECT(ans = allocVector(INTSXP,1));
  INTEGER(ans)[0] = pbv->size();
  UNPROTECT(1);

  return(ans);
}
} 





// necessary methods
//   length()
//   nbits()
//   as.character()
//   [
//   [<-
//   copy?
//   




int test()
{
  vector<bool> bv(10, true);
  vector<bool>::iterator it;

  cout << "First\n";
  for(it=bv.begin(); it != bv.end(); it++)
    {
      cout << *it;
    }
  cout << endl;

  bv.push_back(false);

  ostream_iterator<bool> out(cout, "");

  cout << "Second\n";
  copy(bv.begin(), bv.end(), out);
  cout << endl;

  bool ab[] = {
    true, false, false, true, true,
    true, true, false, false, true 
  };

  bv.assign(ab, ab + sizeof(ab)/sizeof(bool));

  cout << "Third\n";
  copy(bv.begin(), bv.end(), out);
  cout << endl;

  bv.flip();

  cout << "Fourth\n";
  copy(bv.begin(), bv.end(), out);
  cout << endl;

  for(int i=0; i < bv.size(); i++)
    {
      bv[i] = 0;
    }


  cout << "Fifth\n";  
  copy(bv.begin(), bv.end(), out);
  cout << endl;

  cout << "End\n";  
    
}
