#include "readGenes.ped.h"

extern "C" {
void getDimOfFile(char **filename, int *nrow, int *sampleInfoLen, int *nMarker,
		int *errorFlag)
{
  FILE *fp;
  int iFlag, tmpnr, nSampleInfoLen;

  nSampleInfoLen=*sampleInfoLen;

  fp=fopen(filename[0], "r");
  if(fp==NULL) 
  { printf("Can't open file %s!\n", filename[0]); 
    *errorFlag=-1;
    return; 
  }

  // get number of markers
  iFlag=0;
  *nMarker=countWords(fp, iFlag);
  if(*nMarker==-1) {
    printf("Warning! The file %s does not contain ped data!\n", filename[0]);
    *errorFlag=-1;
    return;
  }

  // get number of rows
  tmpnr=countLines(fp, *nMarker, nSampleInfoLen);
  if(tmpnr<0) // error occurs
  { *errorFlag=-1;
    return; 
  }

  *nrow=tmpnr;
  fclose(fp);

  return;  
}

}


int isWhitespace(char c)
{ char whitespace=' ';
  if(c==whitespace)
  { return(1); }
  return(0);
}

// iFlag =1 means we want to check if input is digit
// iFlag =0 means we do not check if input is digit
//int countWords(FILE *fp, fpos_t pos, int iFlag)
int countWords(FILE *fp, int iFlag)
{
  int nc;
  char c, endOfLine='\n', currWhitespace, prevWhitespace=1;

  // get column numbers
  nc = 0;
  do { 
    c=fgetc(fp);
    if(feof(fp)) // reach end of file
    { nc=-1; break; }
    if( c == endOfLine )
    { break;}

    currWhitespace=isWhitespace(c);
    if((iFlag!=0)&&(currWhitespace==0)&&(isalnum(c))&&(!isdigit(c))) //not a digit
    { printf("c=%d, nc=%d\n", c, nc);
      return(-(nc+2)); 
    }

    
    if( currWhitespace==0 && (isalnum(c)) && prevWhitespace==1)
    { nc++; }
    prevWhitespace=currWhitespace;


  } while(1);
  return(nc);
}

int countLines(FILE *fp, int nMarker, int nSampleInfoLen)
{
  int nr, tmpnc, tmpnc2, tmpnc3, flag, iFlag;
  fpos_t pos;

  nr = 0;
  tmpnc2 = 0;
  tmpnc3=nMarker*2+nSampleInfoLen;
  while(1)
  {
    flag=fgetpos(fp, &pos);
    if(flag!=0)
      error("Error in fgetpos()!\n");

    // check if input is digit or not
    iFlag=1;
    tmpnc=countWords(fp, iFlag);
    if(tmpnc==0)
    { break; }
    if(tmpnc==-1) { break; }
    if(tmpnc<0) // error occurs
    { printf("Integer expected. (Line=%d, column=%d) is not an integer!\n",
        (nr+2), -(tmpnc+2)+1);
      return(tmpnc);
    }
    if(nr>0)
    { if(tmpnc!=tmpnc2)
      { printf("number of fields inconsistent with number of markers!\n");
        printf("nMarker=%d, number of fields in line %d is %d\n", nMarker,
                        nr+1, tmpnc);
        printf("expected number of fields in line %d is %d\n",
                        nr+1, tmpnc3);
        return(-1);
      }
    } else
    { tmpnc2=tmpnc; }
    if(tmpnc!=tmpnc3)
    { printf("number of fields inconsistent with number of markers!\n");
      printf("nMarker=%d, number of fields in line %d is %d\n", nMarker, 
		      nr+1, tmpnc);
        printf("expected number of fields in line %d is %d\n",
                        nr+1, tmpnc3);
      return(-1);
    }
    ++nr;
  }
  return(nr);
}

extern "C" {
void getPed(char **filename, int *ped, int *nrow, int *ncol, int *nMarker, 
		char **markerNames, int *errorFlag)
{
  int nr, nc, nM, i, j;
  FILE *fp;
  char *Names;

  nr=*nrow;
  nc=*ncol;
  nM=*nMarker;

  Names=(char *)R_alloc( (long) nM*50, (int) sizeof(char));

  fp=fopen(filename[0], "r");
  if(fp==NULL)
  { printf("cannot open the file %s!n", filename[0]);
    *errorFlag=-1;
    return;
  }

 //read marker names
  for(i=0; i<nM; i++)
  {
    fscanf(fp, "%s", markerNames[i]);
  }
  fscanf(fp, "\n");


  for(i=0; i<nr; i++)
  { for(j=0; j<nc; j++)
    { fscanf(fp, "%d", &ped[i*nc+j]); 
    }
    fscanf(fp, "\n");
  }    
		 
  fclose(fp);
  // free(Names); Automatically peformed for R_alloc
  *errorFlag=0;
  return;
}
}

